@@ -12,6 +12,14 @@ import era5cli.info as einfo
 import era5cli.fetch as efetch
 
 
+def _level_parse(level):
+    """Parse levels as integers, or the string 'surface'"""
+    if level == "surface":
+        return str(level)
+    else:
+        return int(level)
+
+
 def _build_parser():
     """Build the argument parser."""
     parser = argparse.ArgumentParser(
@@ -60,15 +68,16 @@ def _build_parser():
     )
 
     common.add_argument(
-        "--levels", nargs="+", type=int,
+        "--levels", nargs="+", type=_level_parse,
         required=False, default=ref.PLEVELS,
         help=textwrap.dedent('''\
-                             Pressure level(s) to download 3D variables for.
-                             Default is all available levels.
-                             See the Copernicus Climate Data Store website or
-                             run `era5cli info -h` for available pressure
-                             levels.
-
+                            Pressure level(s) to download 3D variables for.
+                            Default is all available levels. See the Copernicus
+                            Climate Data Store website or run `era5cli info -h`
+                            for available pressure levels. For geopotential,
+                            `--levels surface` can be used to request data from
+                            the single level dataset (previously called
+                            orography).
                              ''')
     )
 
@@ -416,10 +425,12 @@ def _execute(args):
         return True
 
 
-def main():
+def main(argv=None):
     """Main."""
     # get arguments
-    args = _parse_args(sys.argv[1:])
+    if argv is None:
+        argv = sys.argv
+    args = _parse_args(argv[1:])
     _execute(args)
 
 
